import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../page_wrapper.dart';

class NotificationListExample extends StatefulWidget {
  NotificationListExample({Key? key}) : super(key: key);

  @override
  State<NotificationListExample> createState() =>
      _NotificationListExampleState();
}

class _NotificationListExampleState extends State<NotificationListExample> {
  bool showLoadButton = true;
  bool showLoading = false;

  void _showSnackbar({
    required BuildContext context,
    required int index,
  }) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.success(
        message: 'Clicou na notificação ${index + 1}',
      ),
    );
  }

  List<SeniorNotification> notifications = [
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: false,
    ),
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: false,
    ),
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
  ];

  void _loadNotification() async {
    setState(() {
      showLoading = true;
    });

    await Future.delayed(
      Duration(seconds: 5),
    );

    notifications.addAll([
      SeniorNotification(
        title: 'Espelho de ponto pendente',
        body: 'Você tem um espelho de ponto pendente',
        footer: '30/10/2021 - 08:42',
        isRead: true,
      ),
      SeniorNotification(
        title: 'Espelho de ponto pendente',
        body: 'Você tem um espelho de ponto pendente',
        footer: '30/10/2021 - 08:42',
        isRead: true,
      ),
      SeniorNotification(
        title: 'Espelho de ponto pendente',
        body: 'Você tem um espelho de ponto pendente',
        footer: '30/10/2021 - 08:42',
        isRead: true,
      ),
      SeniorNotification(
        title: 'Espelho de ponto pendente',
        body: 'Você tem um espelho de ponto pendente',
        footer: '30/10/2021 - 08:42',
        isRead: true,
      ),
    ]);

    if (notifications.length >= 20) {
      showLoadButton = false;
    }

    setState(() {
      showLoading = false;
    });
  }

  _clearNotifications() async {
    setState(() {
      notifications.clear();
      showLoadButton = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Notification List Example',
      content: Center(
        child: SeniorNotificationList(
          title: 'Últimas notificações',
          horizontalPadding: 32,
          actionButtonLabel: 'Limpar',
          onTapActionButton: _clearNotifications,
          onNotificationTap: (index) {
            _showSnackbar(context: context, index: index);
          },
          loadButtonLabel: 'Carregar mais',
          notifications: notifications,
          isLoading: showLoading,
        ),
      ),
    );
  }
}
