import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_action_button_style.dart';
import '../../themes/senior_theme.dart';
import '../../themes/senior_theme_provider.dart';

enum SeniorActionButtonSize {
  small,
  medium,
}

class SeniorActionButton extends StatelessWidget {
  const SeniorActionButton({
    Key? key,
    required this.icon,
    this.onLongPress,
    required this.onTap,
    this.size = SeniorActionButtonSize.small,
    this.style,
  }) : super(key: key);

  final IconData icon;
  final VoidCallback? onLongPress;
  final VoidCallback onTap;
  final SeniorActionButtonSize size;
  final SeniorActionButtonStyle? style;

  factory SeniorActionButton.press({
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) = _SeniorPressActionButton;

  double _getButtonDiameter() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 32.0;
      case SeniorActionButtonSize.medium:
        return 40.0;
    }
  }

  double _getButtonIconSize() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 16.0;
      case SeniorActionButtonSize.medium:
        return 24.0;
    }
  }

  @override
  Widget build(BuildContext context) {
    final double buttonDiameter = _getButtonDiameter();
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: theme?.actionButtonTheme?.style?.color ??
            defaultTheme.actionButtonTheme?.style?.color ??
            Colors.transparent,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.actionButtonTheme?.style?.splashColor ??
            defaultTheme.actionButtonTheme?.style?.splashColor ??
            SeniorColors.neutralColor200,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: FaIcon(
            icon,
            color: style?.iconColor ??
                theme?.actionButtonTheme?.style?.iconColor ??
                defaultTheme.actionButtonTheme?.style?.iconColor ??
                SeniorColors.secondaryColor900,
            size: _getButtonIconSize(),
          ),
        ),
      ),
    );
  }
}

class _SeniorPressActionButton extends SeniorActionButton {
  const _SeniorPressActionButton({
    Key? key,
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) : super(
          key: key,
          icon: icon,
          onLongPress: onLongPress,
          onTap: onTap,
          style: style,
        );

  @override
  Widget build(BuildContext context) {
    final double buttonDiameter = 60.0;
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: style?.color ??
            theme?.pressActionButtonTheme?.style?.color ??
            defaultTheme.pressActionButtonTheme?.style?.color ??
            SeniorColors.primaryColor,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.pressActionButtonTheme?.style?.splashColor ??
            defaultTheme.pressActionButtonTheme?.style?.splashColor ??
            SeniorColors.primaryColor700,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: FaIcon(
            icon,
            color: style?.iconColor ??
                theme?.pressActionButtonTheme?.style?.iconColor ??
                defaultTheme.pressActionButtonTheme?.style?.iconColor ??
                SeniorColors.pureWhite,
          ),
        ),
      ),
    );
  }
}
