import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_balance_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../senior_themes.dart';

enum InfoType {
  expensive,
  revenue,
}

class SeniorBalance extends StatefulWidget {
  const SeniorBalance({
    Key? key,
    required this.expenseLabel,
    required this.expenseValue,
    required this.moneySign,
    required this.revenueLabel,
    required this.revenueValue,
    this.style,
  }) : super(key: key);

  final String expenseLabel;
  final String expenseValue;
  final String moneySign;
  final String revenueLabel;
  final String revenueValue;
  final SeniorBalanceStyle? style;

  @override
  _SeniorBalanceState createState() => _SeniorBalanceState();
}

class _SeniorBalanceState extends State<SeniorBalance> {
  bool _showValues = false;
  final List<InfoType> items = [InfoType.expensive, InfoType.revenue];
  InfoType _type = InfoType.expensive;

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color txtColor = widget.style?.textColor ??
        theme?.balanceTheme?.style?.textColor ??
        defaultTheme.balanceTheme?.style?.textColor ??
        SeniorColors.neutralColor600;

    final Color selecCtrlColor = widget.style?.selectedControllerColor ??
        theme?.balanceTheme?.style?.selectedControllerColor ??
        defaultTheme.balanceTheme?.style?.selectedControllerColor ??
        SeniorColors.neutralColor500;
    
    final Color uselecCtrlColor = widget.style?.unselectedControllerColor ??
        theme?.balanceTheme?.style?.unselectedControllerColor ??
        defaultTheme.balanceTheme?.style?.unselectedControllerColor ??
        SeniorColors.neutralColor200;

    return Container(
      height: 64.0,
      width: double.infinity,
      child: Column(
        children: [
          Expanded(
            child: PageView.builder(
              itemCount: 2,
              physics: BouncingScrollPhysics(),
              onPageChanged: (index) {
                setState(() {
                  _showValues = false;
                  _type = items[index];
                });
              },
              itemBuilder: (_, currentIndex) {
                return Container(
                  child: Column(
                    children: [
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Text(
                            _type == InfoType.expensive
                                ? widget.expenseLabel
                                : widget.revenueLabel,
                            style: SeniorTypography.small(
                              color: txtColor,
                            ),
                          ),
                          //SizedBox(width: 8.0),
                          GestureDetector(
                            onTap: () {
                              setState(() {
                                _showValues = !_showValues;
                              });
                            },
                            child: Padding(
                              padding: const EdgeInsets.only(
                                left: SeniorSpacing.xsmall,
                              ),
                              child: Container(
                                padding: EdgeInsets.all(
                                  SeniorSpacing.xxsmall,
                                ),
                                child: Icon(
                                  _showValues
                                      ? FontAwesomeIcons.eye
                                      : FontAwesomeIcons.eyeSlash,
                                  size: SeniorTypographyIconSize.small,
                                  color: txtColor,
                                ),
                              ),
                            ),
                          )
                        ],
                      ),
                      Padding(
                        padding: const EdgeInsets.only(
                          top: SeniorSpacing.xxsmall,
                        ),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.end,
                          children: [
                            Text(
                              widget.moneySign,
                              style: SeniorTypography.tiny(
                                color: txtColor,
                              ),
                            ),
                            Visibility(
                              visible: _showValues,
                              replacement: Text(
                                '**********',
                                style: SeniorTypography.h3(
                                  color: txtColor,
                                ),
                              ),
                              child: Text(
                                _type == InfoType.expensive
                                    ? widget.expenseValue
                                    : widget.revenueValue,
                                style: SeniorTypography.h3(
                                  color: txtColor,
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                );
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(
              top: SeniorSpacing.xxsmall,
            ),
            child: Row(
              children: [
                Container(
                  height: 2.0,
                  width: 29.0,
                  color: _type == InfoType.expensive
                      ? selecCtrlColor
                      : uselecCtrlColor
                ),
                SizedBox(width: 2.0),
                Container(
                  height: 2.0,
                  width: 29.0,
                  color: _type == InfoType.revenue
                      ? selecCtrlColor
                      : uselecCtrlColor,
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
