import 'package:flutter/material.dart';
import 'package:badges/badges.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_bottom_navigation_bar_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorBottomNavigationBarItem {
  const SeniorBottomNavigationBarItem({
    required this.icon,
    required this.label,
    this.activeIcon,
    this.badgeInfo,
  });

  final IconData icon;
  final String label;
  final IconData? activeIcon;
  final String? badgeInfo;
}

class SeniorBottomNavigationBar extends StatelessWidget {
  const SeniorBottomNavigationBar({
    Key? key,
    required this.currentIndex,
    required this.items,
    required this.onTap,
    this.style,
  }) : super(key: key);

  final int currentIndex;
  final List<SeniorBottomNavigationBarItem> items;
  final Function(int) onTap;
  final SeniorBottomNavigationBarStyle? style;

  Widget _buildIcon({
    required IconData icon,
    required Color badgeColor,
    required Color badgeItemColor,
    String? badgeInfo,
  }) {
    return badgeInfo != null
        ? Badge(
            elevation: 0,
            badgeColor: badgeColor,
            badgeContent: Text(
              badgeInfo,
              style: SeniorTypography.small(
                color: badgeItemColor,
              ),
            ),
            child: FaIcon(icon),
          )
        : FaIcon(icon);
  }

  List<BottomNavigationBarItem> buildBottomNavBarItems({
    required Color color,
    required Color badgeColor,
    required Color badgeItemColor,
  }) {
    List<BottomNavigationBarItem> bottomNavItems = [];

    items.forEach((item) {
      bottomNavItems.add(
        BottomNavigationBarItem(
          icon: _buildIcon(
            icon: item.icon,
            badgeInfo: item.badgeInfo,
            badgeColor: badgeColor,
            badgeItemColor: badgeItemColor,
          ),
          activeIcon: _buildIcon(
            icon: item.activeIcon ?? item.icon,
            badgeInfo: item.badgeInfo,
            badgeColor: badgeColor,
            badgeItemColor: badgeItemColor,
          ),
          label: item.label,
          backgroundColor: color,
        ),
      );
    });

    return bottomNavItems;
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color selectedItemColor = style?.selectedItemColor ??
        theme?.bottomNavigationBarTheme?.style?.selectedItemColor ??
        defaultTheme.bottomNavigationBarTheme?.style?.selectedItemColor ??
        SeniorColors.primaryColor;

    final Color unselectedItemColor = style?.unselectedItemColor ??
        theme?.bottomNavigationBarTheme?.style?.unselectedItemColor ??
        defaultTheme.bottomNavigationBarTheme?.style?.unselectedItemColor ??
        SeniorColors.neutralColor500;

    return BottomNavigationBar(
      key: key,
      backgroundColor: style?.color ??
          theme?.bottomNavigationBarTheme?.style?.color ??
          defaultTheme.bottomNavigationBarTheme?.style?.color ??
          SeniorColors.neutralColor100,
      type: BottomNavigationBarType.fixed,
      items: buildBottomNavBarItems(
        color: style?.color ??
            theme?.bottomNavigationBarTheme?.style?.color ??
            defaultTheme.bottomNavigationBarTheme?.style?.color ??
            SeniorColors.neutralColor100,
        badgeColor: style?.badgeColor ??
            theme?.bottomNavigationBarTheme?.style?.badgeColor ??
            defaultTheme.bottomNavigationBarTheme?.style?.color ??
            SeniorColors.primaryColor,
        badgeItemColor: style?.badgeItemColor ??
            theme?.bottomNavigationBarTheme?.style?.badgeItemColor ??
            defaultTheme.bottomNavigationBarTheme?.style?.badgeItemColor ??
            SeniorColors.pureWhite,
      ),
      currentIndex: currentIndex,
      iconSize: SeniorTypographyIconSize.h4,
      showSelectedLabels: true,
      selectedLabelStyle: SeniorTypography.small(color: selectedItemColor),
      selectedItemColor: selectedItemColor,
      showUnselectedLabels: true,
      unselectedLabelStyle: SeniorTypography.small(color: unselectedItemColor),
      unselectedItemColor: unselectedItemColor,
      onTap: onTap,
    );
  }
}
