import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_checkbox_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorCheckbox extends StatelessWidget {
  const SeniorCheckbox({
    Key? key,
    this.actionOnTitle = false,
    this.disabled = false,
    this.extraTapMargin = 0,
    required this.onChanged,
    this.style,
    this.title,
    required this.value,
  }) : super(key: key);

  final bool actionOnTitle;
  final bool disabled;
  final double extraTapMargin;
  final Function(bool?)? onChanged;
  final SeniorCheckboxStyle? style;
  final String? title;
  final bool value;

  static const double size = Checkbox.width;

  void _handleValueChange() {
    if (!disabled && onChanged != null) {
      onChanged!(!value);
    }
  }

  Widget _buildCheckbox(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return Container(
      width: SeniorCheckbox.size,
      height: SeniorCheckbox.size,
      decoration: BoxDecoration(
        color: SeniorColors.pureWhite,
        border: Border.all(
          color: disabled
              ? style?.disabledBorderColor ??
                  theme?.checkboxTheme?.style?.disabledBorderColor ??
                  defaultTheme.checkboxTheme?.style?.disabledBorderColor ??
                  SeniorColors.secondaryColor300
              : value
                  ? style?.checkedBorderColor ??
                      theme?.checkboxTheme?.style?.checkedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.primaryColor
                  : style?.uncheckedBorderColor ??
                      theme?.checkboxTheme?.style?.uncheckedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.secondaryColor600,
          width: 1,
        ),
        borderRadius: BorderRadius.circular(3),
      ),
      child: Theme(
        data: ThemeData(
          unselectedWidgetColor: Colors.transparent,
          disabledColor: Colors.transparent,
        ),
        child: Checkbox(
          value: value,
          onChanged: null,
          activeColor: Colors.transparent,
          checkColor: disabled
              ? style?.checkColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.secondaryColor300
              : style?.disabledCheckColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.primaryColor,
          materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
        ),
      ),
    );
  }

  Widget _buildTitle(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return title != null
        ? Text(
            title!,
            style: SeniorTypography.text(
              color: disabled
                  ? style?.disabledTitleColor ??
                      theme?.checkboxTheme?.style?.disabledTitleColor ??
                      defaultTheme.checkboxTheme?.style?.disabledTitleColor ??
                      SeniorColors.secondaryColor300
                  : style?.titleColor ??
                      theme?.checkboxTheme?.style?.titleColor ??
                      defaultTheme.checkboxTheme?.style?.titleColor ??
                      SeniorColors.neutralColor900,
            ),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return ListTileTheme.merge(
      child: Stack(
        alignment: Alignment.centerLeft,
        children: [
          GestureDetector(
            onTap: actionOnTitle ? _handleValueChange : null,
            child: Row(
              children: [
                SizedBox(
                  width: extraTapMargin,
                ),
                Padding(
                  padding: title != null ? const EdgeInsets.only(right: SeniorSpacing.xsmall) : EdgeInsets.all(0),
                  child: _buildCheckbox(theme, defaultTheme),
                ),
                _buildTitle(theme, defaultTheme),
              ],
            ),
          ),
          GestureDetector(
            onTap: _handleValueChange,
            child: Container(
              color: Colors.transparent,
              width: extraTapMargin + size + extraTapMargin,
              height: extraTapMargin + size + extraTapMargin,
            ),
          ),
        ],
      ),
    );
  }
}
