import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_dropdown_button_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorDropdownButton extends StatefulWidget {
  const SeniorDropdownButton({
    Key? key,
    this.disabled = false,
    this.helper,
    this.icon,
    required this.items,
    required this.label,
    required this.onChanged,
    this.onTap,
    this.style,
    this.validator,
    required this.value,
  }) : super(key: key);

  final bool disabled;
  final String? helper;
  final IconData? icon;
  final List<DropdownMenuItem> items;
  final String label;
  final Function(dynamic) onChanged;
  final Function()? onTap;
  final SeniorDropdownButtonStyle? style;
  final String? Function(dynamic)? validator;
  final dynamic value;

  @override
  _SeniorDropdownButtonState createState() => _SeniorDropdownButtonState();
}

class _SeniorDropdownButtonState extends State<SeniorDropdownButton> {
  String? _validMsg;
  bool _hasError = false;
  String? _errorMsg;

  @override
  void initState() {
    super.initState();
    _internalValidate(value: widget.value, validateAsError: false);
  }

  void _internalValidate({dynamic value, bool validateAsError = true}) {
    if (widget.validator != null) {
      setState(() {
        _validMsg = widget.validator!(value);

        if (validateAsError) {
          _hasError = _validMsg != null;
          _errorMsg = _validMsg;
        }
      });
    }
  }

  String? _validate(dynamic value) {
    _internalValidate(value: value);
    return _validMsg;
  }

  void _onChanged(dynamic value) {
    widget.onChanged(value);
    _internalValidate(value: value);
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return DropdownButtonFormField(
      dropdownColor: widget.style?.dropdownColor ??
          theme?.dropdownButtonTheme?.style?.dropdownColor ??
          defaultTheme.dropdownButtonTheme?.style?.dropdownColor ??
          SeniorColors.neutralColor100,
      items: widget.items,
      value: widget.value,
      onChanged: !widget.disabled ? _onChanged : null,
      onTap: widget.onTap,
      validator: _validate,
      icon: Icon(
        FontAwesomeIcons.chevronDown,
      ),
      iconSize: SeniorTypographyIconSize.text,
      iconEnabledColor: widget.style?.iconEnabledColor ??
          theme?.dropdownButtonTheme?.style?.iconEnabledColor ??
          defaultTheme.dropdownButtonTheme?.style?.iconEnabledColor ??
          SeniorColors.neutralColor900,
      iconDisabledColor: widget.style?.iconDisabledColor ??
          theme?.dropdownButtonTheme?.style?.iconDisabledColor ??
          defaultTheme.dropdownButtonTheme?.style?.iconDisabledColor ??
          SeniorColors.neutralColor400,
      isExpanded: true,
      decoration: InputDecoration(
        contentPadding: EdgeInsets.symmetric(horizontal: SeniorSpacing.small),
        helperText: widget.helper,
        errorText: _errorMsg,
        prefixIcon: widget.icon == null
            ? null
            : Icon(
                widget.icon,
                size: SeniorTypographyIconSize.CTA,
                color: widget.disabled
                    ? widget.style?.disabledIconColor ??
                        theme?.dropdownButtonTheme?.style?.disabledIconColor ??
                        defaultTheme.dropdownButtonTheme?.style?.disabledIconColor ??
                        SeniorColors.secondaryColor900
                    : widget.style?.iconColor ??
                        theme?.dropdownButtonTheme?.style?.iconColor ??
                        defaultTheme.dropdownButtonTheme?.style?.iconColor ??
                        SeniorColors.neutralColor400,
              ),
        labelText: widget.label,
        labelStyle: SeniorTypography.text(
          color: _hasError
              ? widget.style?.errorColor ??
                  theme?.dropdownButtonTheme?.style?.errorColor ??
                  defaultTheme.dropdownButtonTheme?.style?.errorColor ??
                  SeniorColors.manchesterColorRed
              : widget.disabled
                  ? widget.style?.disabledLabelColor ??
                      theme?.dropdownButtonTheme?.style?.disabledLabelColor ??
                      defaultTheme.dropdownButtonTheme?.style?.disabledLabelColor ??
                      SeniorColors.neutralColor400
                  : widget.style?.labelColor ??
                      theme?.dropdownButtonTheme?.style?.labelColor ??
                      defaultTheme.dropdownButtonTheme?.style?.labelColor ??
                      SeniorColors.primaryColor600,
        ),
        border: UnderlineInputBorder(
          borderSide: BorderSide(
            color: widget.style?.borderColor ??
                theme?.dropdownButtonTheme?.style?.borderColor ??
                defaultTheme.dropdownButtonTheme?.style?.borderColor ??
                SeniorColors.secondaryColor500,
            width: 2.0,
          ),
        ),
      ),
      style: SeniorTypography.text(
        color: widget.style?.textColor ??
            theme?.dropdownButtonTheme?.style?.textColor ??
            defaultTheme.dropdownButtonTheme?.style?.textColor ??
            SeniorColors.neutralColor800,
      ),
    );
  }
}
