import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_expansion_panel_list_style.dart';
import '../../components/senior_button/senior_button_widget.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorPanelData {
  SeniorPanelData({
    this.actions,
    this.expandedInfo,
    required this.headerInfo,
    this.isExpanded = false,
    this.severityColor = SeniorColors.neutralColor100,
  });

  final List<SeniorButton>? actions;
  final Widget? expandedInfo;
  final Widget headerInfo;
  bool isExpanded;
  final Color severityColor;
}

class SeniorExpansionPanelList extends StatelessWidget {
  const SeniorExpansionPanelList({
    Key? key,
    required this.expansionCallback,
    required this.list,
    this.style,
  }) : super(key: key);

  final ExpansionPanelCallback expansionCallback;
  final List<SeniorPanelData> list;
  final SeniorExpansionPanelListStyle? style;

  final Duration animationDuration = kThemeAnimationDuration;

  bool _isChildExpanded(int index) {
    return list[index].isExpanded;
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);
    final List<Widget> items = [];

    final Color backgroundColor = style?.backgroundColor ??
        theme?.expansionPanelListTheme?.style?.backgroundColor ??
        defaultTheme.expansionPanelListTheme?.style?.backgroundColor ??
        SeniorColors.neutralColor100;

    for (int index = 0; index < list.length; index += 1) {
      if (index != 0) {
        items.add(Divider(height: 15.0));
      }

      final Widget header = Row(
        children: <Widget>[
          Expanded(
            child: AnimatedContainer(
              duration: animationDuration,
              curve: Curves.fastOutSlowIn,
              child: ListTile(
                contentPadding: EdgeInsets.symmetric(horizontal: SeniorSpacing.normal),
                title: list[index].headerInfo,
              ),
            ),
          ),
          ExpandIcon(
            isExpanded: _isChildExpanded(index),
            padding: const EdgeInsets.all(SeniorSpacing.normal),
            size: SeniorTypographyIconSize.CTA,
            onPressed: (bool isExpanded) {
              expansionCallback(index, isExpanded);
            },
          ),
        ],
      );

      final Widget body = AnimatedCrossFade(
        firstChild: Container(),
        secondChild: Container(
          width: double.maxFinite,
          padding: const EdgeInsets.symmetric(horizontal: SeniorSpacing.small, vertical: SeniorSpacing.normal),
          child: Column(
            children: [
              list[index].expandedInfo ?? Container(),
              Padding(
                padding: const EdgeInsets.only(top: SeniorSpacing.big),
                child: Row(
                  children: list[index].actions != null
                      ? list[index]
                          .actions!
                          .asMap()
                          .map((i, action) => MapEntry(
                              i,
                              Expanded(
                                child: Container(
                                  margin: i != list[index].actions!.length - 1
                                      ? EdgeInsets.only(right: SeniorSpacing.small)
                                      : EdgeInsets.all(0),
                                  child: action,
                                ),
                              )))
                          .values
                          .toList()
                      : [],
                ),
              ),
            ],
          ),
        ),
        firstCurve: const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
        secondCurve: const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
        sizeCurve: Curves.fastOutSlowIn,
        crossFadeState: _isChildExpanded(index) ? CrossFadeState.showSecond : CrossFadeState.showFirst,
        duration: animationDuration,
      );

      items.add(
        Container(
          decoration: BoxDecoration(
            color: backgroundColor,
            borderRadius: BorderRadius.all(Radius.circular(SeniorRadius.xbig)),
            gradient: LinearGradient(
              end: const Alignment(-0.97, 0),
              begin: const Alignment(-0.98, 0),
              colors: [list[index].severityColor, backgroundColor],
            ),
          ),
          child: Column(
            children: <Widget>[
              header,
              body,
            ],
          ),
        ),
      );
    }

    return Column(
      children: items,
    );
  }
}
