import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_menu_list_item_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorMenuItemList extends StatelessWidget {
  const SeniorMenuItemList({
    Key? key,
    this.iconData,
    required this.title,
    this.onTap,
    this.subtitle,
    this.enabled = true,
    this.leftPadding = 0,
    this.rightPadding = 0,
    this.style,
  }) : super(key: key);

  final IconData? iconData;
  final String title;
  final String? subtitle;
  final VoidCallback? onTap;
  final bool enabled;
  final double leftPadding;
  final double rightPadding;
  final SeniorMenuListItemStyle? style;

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Material(
      color: Colors.transparent,
      child: InkWell(
        onTap: enabled ? onTap : null,
        child: Container(
          padding: EdgeInsets.only(
            top: SeniorSpacing.small,
            bottom: SeniorSpacing.small,
            left: leftPadding,
            right: rightPadding,
          ),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              iconData != null
                  ? Padding(
                      padding: const EdgeInsets.only(
                        right: SeniorSpacing.small,
                      ),
                      child: Icon(
                        iconData,
                        size: 20,
                        color: style?.iconColor ??
                            theme?.menuListItemTheme?.style?.iconColor ??
                            defaultTheme.menuListItemTheme?.style?.iconColor ??
                            SeniorColors.primaryColor500,
                      ),
                    )
                  : SizedBox.shrink(),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Text(
                      title,
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                      textAlign: TextAlign.left,
                      style: SeniorTypography.body(
                        color: style?.titleColor ??
                            theme?.menuListItemTheme?.style?.titleColor ??
                            defaultTheme.menuListItemTheme?.style?.titleColor ??
                            SeniorColors.primaryColor900,
                      ),
                    ),
                    subtitle == null
                        ? SizedBox.shrink()
                        : Text(
                            subtitle!,
                            textAlign: TextAlign.left,
                            style: SeniorTypography.body(
                              color: style?.subtitleColor ??
                                  theme?.menuListItemTheme?.style?.subtitleColor ??
                                  defaultTheme.menuListItemTheme?.style?.subtitleColor ??
                                  SeniorColors.primaryColor900,
                            ),
                          ),
                  ],
                ),
              ),
              Offstage(
                offstage: onTap == null,
                child: Align(
                  alignment: Alignment.center,
                  child: Icon(
                    FontAwesomeIcons.angleRight,
                    color: enabled
                        ? style?.pushIconColor ??
                            theme?.menuListItemTheme?.style?.pushIconColor ??
                            defaultTheme.menuListItemTheme?.style?.pushIconColor ??
                            SeniorColors.primaryColor500
                        : style?.disabledPushIconColor ??
                            theme?.menuListItemTheme?.style?.disabledPushIconColor ??
                            defaultTheme.menuListItemTheme?.style?.disabledPushIconColor ??
                            SeniorColors.neutralColor900,
                    size: 20,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
