import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_modal_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../components/senior_button/senior_button.dart';
import '../../themes/senior_theme.dart';

class SeniorModal extends StatelessWidget {
  const SeniorModal({
    Key? key,
    this.actionButton,
    required this.content,
    required this.ghostButton,
    this.style,
    required this.title,
  }) : super(key: key);

  final SeniorButton? actionButton;
  final String content;
  final SeniorButton ghostButton;
  final SeniorModalStyle? style;
  final String title;

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return AlertDialog(
      backgroundColor: style?.backgroundColor ??
          theme?.modalTheme?.style?.backgroundColor ??
          defaultTheme.modalTheme?.style?.backgroundColor ??
          null,
      title: Text(
        title,
        style: SeniorTypography.h3(
          color: SeniorColors.neutralColor800,
        ),
      ),
      titlePadding: EdgeInsets.only(
        top: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        left: SeniorSpacing.normal,
        bottom: SeniorSpacing.xsmall,
      ),
      contentPadding: EdgeInsets.only(
        left: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        bottom: SeniorSpacing.normal,
      ),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Expanded(
            child: SingleChildScrollView(
              child: Text(
                content,
                style: SeniorTypography.text(
                  color: style?.backgroundColor ??
                      theme?.modalTheme?.style?.backgroundColor ??
                      defaultTheme.modalTheme?.style?.backgroundColor ??
                      SeniorColors.secondaryColor,
                ),
              ),
            ),
          ),
          SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          actionButton ?? SizedBox.shrink(),
          SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          ghostButton
        ],
      ),
    );
  }
}
