import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_notification_list_style.dart';
import '../../components/senior_button/senior_button.dart';
import '../../components/senior_loading/senior_loading.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorNotification {
  final String body;
  final String footer;
  final bool isRead;
  final String title;

  const SeniorNotification({
    required this.body,
    required this.footer,
    required this.isRead,
    required this.title,
  });
}

class SeniorNotificationList extends StatelessWidget {
  const SeniorNotificationList({
    Key? key,
    this.actionButtonLabel,
    this.busyActionButton = false,
    this.disabledActionButton = false,
    this.horizontalPadding = 0,
    this.isLoading = false,
    this.loadButtonLabel,
    required this.notifications,
    this.onLoad,
    this.onNotificationTap,
    this.onTapActionButton,
    this.scrollController,
    this.style,
    required this.title,
  }) : super(key: key);

  final String? actionButtonLabel;
  final bool busyActionButton;
  final bool disabledActionButton;
  final double horizontalPadding;
  final bool isLoading;
  final String? loadButtonLabel;
  final List<SeniorNotification> notifications;
  final Function()? onLoad;
  final Function(int)? onNotificationTap;
  final Function()? onTapActionButton;
  final ScrollController? scrollController;
  final SeniorNotificationListStyle? style;
  final String title;

  Widget _buildNotification(SeniorNotification notification, SeniorTheme? theme, SeniorTheme defaultTheme) {
    return InkWell(
      child: Container(
        padding: EdgeInsets.symmetric(
          horizontal: horizontalPadding,
          vertical: SeniorSpacing.normal,
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                bottom: SeniorSpacing.xsmall,
              ),
              child: Text(
                notification.title,
                style: SeniorTypography.body(
                  color: style?.notificationTitleColor ??
                      theme?.notificationListTheme?.style?.notificationTitleColor ??
                      defaultTheme.notificationListTheme?.style?.notificationTitleColor ??
                      SeniorColors.pureBlack,
                ).copyWith(
                  fontWeight: notification.isRead ? FontWeight.normal : FontWeight.bold,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(
                bottom: SeniorSpacing.xsmall,
              ),
              child: Text(
                notification.body,
                style: SeniorTypography.body(
                  color: style?.notificationBodyColor ??
                      theme?.notificationListTheme?.style?.notificationBodyColor ??
                      defaultTheme.notificationListTheme?.style?.notificationBodyColor ??
                      SeniorColors.neutralColor800,
                ),
              ),
            ),
            Text(
              notification.footer,
              style: SeniorTypography.helper(
                color: style?.notificationFooterColor ??
                    theme?.notificationListTheme?.style?.notificationFooterColor ??
                    defaultTheme.notificationListTheme?.style?.notificationFooterColor ??
                    SeniorColors.neutralColor500,
              ),
            ),
          ],
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);
    final padding = MediaQuery.of(context).padding;

    return Container(
      child: Column(
        children: [
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: SeniorSpacing.xmedium,
                vertical: SeniorSpacing.small,
              ),
              child: Text(
                title,
                style: SeniorTypography.body(
                  color: style?.titleColor ??
                      theme?.notificationListTheme?.style?.titleColor ??
                      defaultTheme.notificationListTheme?.style?.titleColor ??
                      SeniorColors.neutralColor800,
                ),
              ),
            ),
          ),
          Expanded(
            child: Scrollbar(
              controller: scrollController,
              child: ListView.separated(
                padding: EdgeInsets.zero,
                controller: scrollController,
                scrollDirection: Axis.vertical,
                shrinkWrap: true,
                itemCount: notifications.length + 1,
                separatorBuilder: (context, index) {
                  return Container(
                    margin: EdgeInsets.symmetric(
                      horizontal: SeniorSpacing.normal,
                    ),
                    height: SeniorSpacing.xxxsmall,
                    color: style?.separatorColor ??
                        theme?.notificationListTheme?.style?.separatorColor ??
                        defaultTheme.notificationListTheme?.style?.separatorColor ??
                        SeniorColors.neutralColor300,
                  );
                },
                itemBuilder: (context, index) {
                  if (index == notifications.length) {
                    if (isLoading) {
                      return Padding(
                        padding: const EdgeInsets.all(
                          SeniorSpacing.normal,
                        ),
                        child: Center(
                          child: SeniorLoading(),
                        ),
                      );
                    }

                    return onLoad != null && loadButtonLabel != null && !isLoading
                        ? Padding(
                            padding: const EdgeInsets.all(SeniorSpacing.normal),
                            child: SeniorButton(
                              label: loadButtonLabel!,
                              type: SeniorButtonType.ghost,
                              size: SeniorButtonSize.small,
                              onPressed: onLoad!,
                            ),
                          )
                        : const SizedBox.shrink();
                  }
                  return InkWell(
                    onTap: onNotificationTap != null ? () => onNotificationTap!(index) : null,
                    child: _buildNotification(notifications[index], theme, defaultTheme),
                  );
                },
              ),
            ),
          ),
          (onTapActionButton != null && actionButtonLabel != null)
              ? Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.normal),
                  child: SeniorButton(
                    label: actionButtonLabel!,
                    type: SeniorButtonType.ghost,
                    onPressed: onTapActionButton!,
                    fullLength: true,
                    busy: busyActionButton,
                    disabled: disabledActionButton,
                  ),
                )
              : const SizedBox.shrink(),
          SizedBox(
            height: padding.bottom,
          ),
        ],
      ),
    );
  }
}
