import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_radio_button_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorRadioButton<T> extends StatelessWidget {
  const SeniorRadioButton({
    Key? key,
    this.disabled = false,
    required this.groupValue,
    required this.onChanged,
    this.style,
    this.toggleable = false,
    required this.title,
    required this.value,
  }) : super(key: key);

  final bool disabled;
  final T groupValue;
  final Function(T?) onChanged;
  final SeniorRadioButtonStyle? style;
  final String title;
  final bool toggleable;
  final T value;

  Container _buildRadioButton(Color fillColor) {
    return Container(
          height: 16.0,
          width: 16.0,
          margin: EdgeInsets.only(right: SeniorSpacing.xsmall),
          child: Radio<T?>(
            key: key,
            groupValue: groupValue,
            value: value,
            onChanged: !disabled ? onChanged : null,
            fillColor: MaterialStateColor.resolveWith(
              (state) => fillColor,
            ),
            toggleable: toggleable,
          ),
        );
  }

  Flexible _buildTitle(Color titleColor) {
    return Flexible(
      child: Text(
        title,
        style: SeniorTypography.text(
          color: titleColor,
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color titleColor = disabled
        ? style?.disabledTitleColor ??
            theme?.radioButtonTheme?.style?.disabledTitleColor ??
            defaultTheme.radioButtonTheme?.style?.disabledTitleColor ??
            SeniorColors.secondaryColor300
        : style?.titleColor ??
            theme?.radioButtonTheme?.style?.titleColor ??
            defaultTheme.radioButtonTheme?.style?.titleColor ??
            SeniorColors.neutralColor900;

    final Color fillColor = disabled
        ? style?.disabledFillColor ??
            theme?.radioButtonTheme?.style?.disabledFillColor ??
            defaultTheme.radioButtonTheme?.style?.disabledFillColor ??
            SeniorColors.secondaryColor300
        : style?.fillColor ??
            theme?.radioButtonTheme?.style?.fillColor ??
            defaultTheme.radioButtonTheme?.style?.fillColor ??
            SeniorColors.primaryColor;

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 0, vertical: 8.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildRadioButton(fillColor),
          _buildTitle(titleColor),
        ],
      ),
    );
  }
}
