import 'package:flutter/cupertino.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_switch_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

enum SeniorSwitchTitlePosition {
  left,
  right,
}

class SeniorSwitch extends StatelessWidget {
  const SeniorSwitch({
    Key? key,
    this.disabled = false,
    this.fullLenght = false,
    this.titlePosition = SeniorSwitchTitlePosition.left,
    required this.onChanged,
    this.style,
    this.title,
    required this.value,
  }) : super(key: key);

  final bool disabled;
  final bool fullLenght;
  final SeniorSwitchTitlePosition titlePosition;
  final Function(bool?) onChanged;
  final SeniorSwitchStyle? style;
  final String? title;
  final bool value;

  Widget _buildSwitch(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return Transform.scale(
      scale: 0.7,
      child: CupertinoSwitch(
        activeColor: style?.activeColor ??
            theme?.switchTheme?.style?.activeColor ??
            defaultTheme.switchTheme?.style?.activeColor ??
            SeniorColors.primaryColor,
        onChanged: !disabled ? onChanged : null,
        trackColor: style?.trackColor ??
            theme?.switchTheme?.style?.trackColor ??
            defaultTheme.switchTheme?.style?.trackColor ??
            SeniorColors.secondaryColor600,
        value: value,
      ),
    );
  }

  Widget _buildTitle(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return title != null
        ? Flexible(
            child: Text(
              title!,
              style: SeniorTypography.text(
                color: disabled
                    ? style?.disabledTextColor ??
                        theme?.switchTheme?.style?.disabledTextColor ??
                        defaultTheme.switchTheme?.style?.disabledTextColor ??
                        SeniorColors.secondaryColor300
                    : style?.textColor ??
                        theme?.switchTheme?.style?.textColor ??
                        defaultTheme.switchTheme?.style?.textColor ??
                        SeniorColors.neutralColor900,
              ),
            ),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Row(
      mainAxisAlignment: fullLenght ? MainAxisAlignment.spaceBetween : MainAxisAlignment.start,
      children: titlePosition == SeniorSwitchTitlePosition.left
          ? [_buildTitle(theme, defaultTheme), _buildSwitch(theme, defaultTheme)]
          : [_buildSwitch(theme, defaultTheme), _buildTitle(theme, defaultTheme)],
    );
  }
}
