import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_tab_bar_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorTabBar extends StatelessWidget implements PreferredSizeWidget {
  const SeniorTabBar({
    Key? key,
    required this.tabs,
    required this.initialIndex,
    required this.onTap,
    this.isScrollable = false,
    this.controller,
    this.style,
  }) : super(key: key);

  final List<String> tabs;
  final int initialIndex;
  final bool isScrollable;
  final Function(int) onTap;
  final TabController? controller;
  final SeniorTabBarStyle? style;

  @override
  Size get preferredSize => const Size.fromHeight(100.0);

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color labelColor = style?.labelColor ??
        theme?.tabBarTheme?.style?.labelColor ??
        defaultTheme.tabBarTheme?.style?.labelColor ??
        SeniorColors.neutralColor800;

    final Color unselectedLabelColor = style?.unselectedLabelColor ??
        theme?.tabBarTheme?.style?.unselectedLabelColor ??
        defaultTheme.tabBarTheme?.style?.unselectedLabelColor ??
        SeniorColors.neutralColor500;

    final Color indicatorColor = style?.indicatorColor ??
        theme?.tabBarTheme?.style?.indicatorColor ??
        defaultTheme.tabBarTheme?.style?.indicatorColor ??
        SeniorColors.primaryColor;

    return TabBar(
      tabs: tabs.map((tab) => Tab(text: tab)).toList(),
      labelColor: labelColor,
      unselectedLabelColor: unselectedLabelColor,
      indicatorColor: indicatorColor,
      labelStyle: SeniorTypography.body(
        color: labelColor,
      ),
      indicatorWeight: 2.0,
      isScrollable: isScrollable,
      onTap: onTap,
      controller: controller,
    );
  }
}
