# SeniorDropdownButton class

Use SeniorDropdownButton para adicionar widgets do tipo dropdown button com as definições do Senior Design System no seu layout.

## Herança

Object > DiagnosticableTree > Widget > __StatefulWidget__

## Construtores

* SeniorDropdownButton({
    Key? key,
    required List< DropdownMenuItem >items,
    required dynamic value,
    bool disabled = false,
    required Function(dynamic) onChanged,
    Function()? onTap,
    required String label,
    String? helper,
    IconData? icon,
    String? Function(dynamic)? validator,
}) ... __const__

## Propriedades

| Property  | Type                      | Description                                                                                                                   | Required | Default |
| --------- | ------------------------- | ----------------------------------------------------------------------------------------------------------------------------- | -------- | ------- |
| key       | Key                       | Controla como um widget substitui outro widget na árvore.                                                                     | Não      |         |
| items     | List< DropdownMenuItem >  | Itens que são apresentados na lista do dropdown button.                                                                       | Sim      |         |
| value     | dynamic                   | O valor do DropdownMenuItem atualmente selecionado .                                                                          | Sim      |         |
| disabled  | bool                      | Determina se o dropdown button estará desabilitado.                                                                           | Não      | false   |
| onChanged | Function(dynamic)         | Função chamada ao selecionar um item.                                                                                         | Sim      |         |
| onTap     | Function()                | Função chamada quando o dropdown button é tocado.                                                                             | Não      |         |
| label     | String                    | Texto de identificação para o dropdown button.                                                                                | Não      |         |
| helper    | String                    | Texto com dica apresentado abaixo do dropdown button.                                                                         | Não      |         |
| icon      | IconData                  | Um ícone apresentado junto ao dropdown button.                                                                                | Não      |         |
| validator | String? Function(dynamic) | Um método opcional que valida o valor selecionado. Retorna uma string de erro se o valor for inválida ou nula caso contrário. | Não      |         |

## Código

```dart
SeniorDropdownButton(
    items: [
        DropdownMenuItem(child: Text('Opção 1'), value: 1),
        DropdownMenuItem(child: Text('Opção 2'), value: 2),
        DropdownMenuItem(child: Text('Opção 3'), value: 3),
    ],
    label: 'Opções',
    value: 2,
    onChanged: (value) {},
    validator: (value) => value == 2 ? 'Inválido' : null,
)
```