import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../senior_theme.dart';
import '../../components/senior_action_button/senior_action_button.dart';
import '../../components/senior_balance/senior_balance.dart';
import '../../components/senior_bottom_navigation_bar/senior_bottom_navigation_bar.dart';
import '../../components/senior_bottom_sheet/senior_bottom_sheet.dart';
import '../../components/senior_button/senior_button.dart';
import '../../components/senior_card/senior_card.dart';
import '../../components/senior_checkbox/senior_checkbox.dart';
import '../../components/senior_contact_book_item/senior_contact_book_item.dart';
import '../../components/senior_dropdown_button/senior_dropdown_button.dart';
import '../../components/senior_expansion_panel_list/senior_expansion_panel_list.dart';
import '../../components/senior_info_card/senior_info_card.dart';
import '../../components/senior_loading/senior_loading.dart';
import '../../components/senior_menu_list_item/senior_menu_list_item.dart';
import '../../components/senior_message_card/senior_message_card.dart';
import '../../components/senior_modal/senior_modal.dart';
import '../../components/senior_notification_list/senior_notification_list.dart';
import '../../components/senior_profile_picture/senior_profile_picture.dart';
import '../../components/senior_quotes/senior_quotes.dart';
import '../../components/senior_radio_button/senior_radio_button.dart';
import '../../components/senior_rating/senior_rating.dart';
import '../../components/senior_snackbar/senior_snackbar.dart';
import '../../components/senior_square_buttons_menu/senior_square_buttons_menu.dart';
import '../../components/senior_switch/senior_switch.dart';
import '../../components/senior_tab_bar/senior_tab_bar.dart';
import '../../components/senior_text_field/senior_text_field.dart';

final SeniorTheme seniorLightTheme = SeniorTheme(
  // Action button
  actionButtonTheme: SeniorActionButtonThemeData(
    style: SeniorActionButtonStyle(
      color: Colors.transparent,
      iconColor: SeniorColors.secondaryColor900,
    ),
  ),
  pressActionButtonTheme: SeniorActionButtonThemeData(
    style: SeniorActionButtonStyle(
      color: SeniorColors.primaryColor,
      iconColor: SeniorColors.pureWhite,
    ),
  ),

  // Balance
  balanceTheme: SeniorBalanceThemeData(
    style: SeniorBalanceStyle(
      textColor: SeniorColors.neutralColor600,
      selectedControllerColor: SeniorColors.neutralColor500,
      unselectedControllerColor: SeniorColors.neutralColor200,
    ),
  ),

  // Bottom sheet
  bottomSheetTheme: SeniorBottomSheetThemeData(
    style: SeniorBottomSheetStyle(
      backgroundColor: SeniorColors.pureWhite,
      closeButtonColor: SeniorColors.manchesterColorRed,
      titleColor: SeniorColors.neutralColor900,
    ),
  ),

  // Bottom navigation bar
  bottomNavigationBarTheme: SeniorBottomNavigationBarThemeData(
    style: SeniorBottomNavigationBarStyle(
      color: SeniorColors.neutralColor100,
      selectedItemColor: SeniorColors.primaryColor,
      unselectedItemColor: SeniorColors.neutralColor500,
      badgeColor: SeniorColors.primaryColor,
      badgeItemColor: SeniorColors.pureWhite,
    ),
  ),

  // Buttons
  primaryButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.primaryColor,
      disabledColor: SeniorColors.primaryColor100,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.primaryColor300,
      waveColor: SeniorColors.primaryColor100,
    ),
  ),
  secondaryButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.secondaryColor,
      disabledColor: SeniorColors.secondaryColor100,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.secondaryColor400,
      waveColor: SeniorColors.secondaryColor100,
    ),
  ),
  ghostButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: Colors.transparent,
      disabledFontColor: Colors.transparent,
      fontColor: SeniorColors.primaryColor,
      disabledColor: SeniorColors.primaryColor100,
      waveColor: SeniorColors.neutralColor400,
    ),
  ),
  dangerButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.manchesterColorRed,
      disabledColor: SeniorColors.manchesterColorRed300,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.pureWhite,
      waveColor: SeniorColors.manchesterColorRed100,
    ),
  ),

  // Card
  cardTheme: SeniorCardThemeData(
    style: SeniorCardStyle(
      backgroundColor: SeniorColors.neutralColor100,
      iconColor: SeniorColors.neutralColor600,
    ),
    borderRadius: SeniorRadius.xbig,
    iconSize: SeniorTypographyIconSize.body,
  ),

  // Checkbox
  checkboxTheme: SeniorCheckboxThemeData(
    style: SeniorCheckboxStyle(
      activeColor: Colors.transparent,
    ),
  ),

  // Contact book item
  contactBookItemTheme: SeniorContactBookItemThemeData(
    style: SeniorContactBookItemStyle(
      itemsColor: SeniorColors.neutralColor500,
      titleColor: SeniorColors.neutralColor800,
    ),
  ),

  // Dropdown button
  dropdownButtonTheme: SeniorDropdownButtonThemeData(
    style: SeniorDropdownButtonStyle(
      borderColor: SeniorColors.secondaryColor500,
      iconColor: SeniorColors.neutralColor400,
      iconDisabledColor: SeniorColors.neutralColor400,
      iconEnabledColor: SeniorColors.neutralColor900,
      disabledIconColor: SeniorColors.secondaryColor900,
      disabledLabelColor: SeniorColors.neutralColor400,
      errorColor: SeniorColors.manchesterColorRed,
      labelColor: SeniorColors.primaryColor600,
      textColor: SeniorColors.neutralColor800,
    ),
  ),

  // Expansion panel list
  expansionPanelListTheme: SeniorExpansionPanelListThemeData(
    style: SeniorExpansionPanelListStyle(
      backgroundColor: SeniorColors.neutralColor100,
    ),
  ),

  // Info card
  infoCardTheme: SeniorInfoCardThemeData(
    style: SeniorInfoCardStyle(
      color: SeniorColors.neutralColor100,
      infoColor: SeniorColors.neutralColor800,
      labelColor: SeniorColors.neutralColor600,
    ),
  ),

  // Loading
  loadingTheme: SeniorLoadingThemeData(
    style: SeniorLoadingStyle(
      color: SeniorColors.primaryColor500,
    ),
  ),

  // Message card
  messageCardTheme: SeniorMessageCardThemeData(
    style: SeniorMessageCardStyle(
      color: SeniorColors.secondaryColor100,
      textColor: SeniorColors.pureBlack,
      feedbackItemsColor: SeniorColors.neutralColor600,
    ),
  ),

  // Menu list item
  menuListItemTheme: SeniorMenuListItemThemeData(
    style: SeniorMenuListItemStyle(
      disabledPushIconColor: SeniorColors.neutralColor900,
      iconColor: SeniorColors.primaryColor500,
      pushIconColor: SeniorColors.primaryColor500,
      subtitleColor: SeniorColors.primaryColor900,
      titleColor: SeniorColors.primaryColor900,
    ),
  ),

  // Modal
  modalTheme: SeniorModalThemeData(
    style: SeniorModalStyle(
      backgroundColor: SeniorColors.secondaryColor,
    ),
  ),

  // Notification list
  notificationListTheme: SeniorNotificationListThemeData(
    style: SeniorNotificationListStyle(
      titleColor: SeniorColors.neutralColor800,
      notificationBodyColor: SeniorColors.neutralColor800,
      notificationFooterColor: SeniorColors.neutralColor500,
      notificationTitleColor: SeniorColors.pureBlack,
      separatorColor: SeniorColors.neutralColor300,
    ),
  ),

  // Profile picture
  profilePictureTheme: SeniorProfilePictureThemeData(
    style: SeniorProfilePictureStyle(
      backgroundColor: SeniorColors.secondaryColor400,
      loadingOverlappingdColor: SeniorColors.pureWhite.withOpacity(.5),
      textColor: SeniorColors.pureBlack,
    ),
  ),

  // Quotes
  quotesTheme: SeniorQuotesThemeData(
    style: SeniorQuotesStyle(
      backgroundColor: SeniorColors.secondaryColor100,
      textColor: SeniorColors.neutralColor800,
    ),
  ),

  // Radio button
  radioButtonTheme: SeniorRadioButtonThemeData(
    style: SeniorRadioButtonStyle(
      disabledFillColor: SeniorColors.secondaryColor300,
      disabledTitleColor: SeniorColors.secondaryColor300,
      fillColor: SeniorColors.primaryColor,
      titleColor: SeniorColors.neutralColor900,
    ),
  ),

  // Rating
  ratingTheme: SeniorRatingThemeData(
    style: SeniorRatingStyle(
      iconColor: SeniorColors.manchesterColorYellow,
      disabledIconColor: SeniorColors.secondaryColor600,
    ),
  ),

  // Snackbar
  successSnackbarTheme: SeniorSnackbarThemeData(
    style: SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorGreen100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorGreen,
    ),
  ),
  messageSnackbarTheme: SeniorSnackbarThemeData(
    style: SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorBlue100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorBlue,
    ),
  ),
  warningSnackbarTheme: SeniorSnackbarThemeData(
    style: SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorYellow100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorYellow,
    ),
  ),
  errorSnackbarTheme: SeniorSnackbarThemeData(
    style: SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorRed100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorRed,
    ),
  ),

  // Square buttons menu
  primarySquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
        backgroundGradientColors: SeniorColors.primaryGradientColors,
        backgroundColor: Colors.red,
        disabledBackgroundColor: SeniorColors.primaryColor.withOpacity(0.3),
        fontColor: SeniorColors.pureWhite,
        disabledFontColor: SeniorColors.pureWhite),
  ),

  secondarySquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: SeniorColors.secondaryColor600,
      disabledBackgroundColor: SeniorColors.secondaryColor600.withOpacity(0.3),
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.pureWhite,
    ),
  ),

  ghostSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: Colors.transparent,
      disabledBackgroundColor: Colors.transparent,
      fontColor: SeniorColors.secondaryColor600,
      disabledFontColor: SeniorColors.secondaryColor600,
    ),
  ),

  // Switch
  switchTheme: SeniorSwitchThemeData(
    style: SeniorSwitchStyle(
      activeColor: SeniorColors.primaryColor,
      disabledTextColor: SeniorColors.secondaryColor300,
      textColor: SeniorColors.neutralColor900,
      trackColor: SeniorColors.secondaryColor600,
    ),
  ),

  // Tab bar
  tabBarTheme: SeniorTabBarThemeData(
    style: SeniorTabBarStyle(
      indicatorColor: SeniorColors.primaryColor,
      labelColor: SeniorColors.neutralColor800,
      unselectedLabelColor: SeniorColors.neutralColor500,
    ),
  ),

  // Text field
  textFieldTheme: SeniorTextFieldThemeData(
    style: SeniorTextFieldStyle(
      counterColor: SeniorColors.neutralColor700,
      errorColor: SeniorColors.manchesterColorRed,
      fillColor: SeniorColors.neutralColor100,
      focusedBorderColor: SeniorColors.primaryColor,
      focusedLabelColor: SeniorColors.primaryColor500,
      helperColor: SeniorColors.neutralColor700,
      hintColor: SeniorColors.neutralColor600,
      iconColor: SeniorColors.neutralColor900,
      textColor: SeniorColors.neutralColor900,
      unfocusedLabelColor: SeniorColors.neutralColor900,
    ),
  ),

  themeData: ThemeData(
    primaryColor: SeniorColors.primaryColor,
  ),
);
