"""Common methods to exec helm commands"""

import sys
import yaml

sys.path.append("./senior-ci")

from common import (
    exec_command_without_print,
    exit_message,
    get_env_variable,
    get_commit_tag_as_semver,
)


def add_nexus_repo():
    nexus_username = get_env_variable("NEXUS_USERNAME")
    nexus_password = get_env_variable("NEXUS_PASSWORD")

    exec_command_without_print(
        f"helm repo add nexus-senior https://nexus.senior.com.br/repository/helm/ --username {nexus_username} --password {nexus_password}"
    )


def get_version():
    with open("./helm/Chart.yaml", "r") as stream:
        try:
            chart = yaml.safe_load(stream)

            version = chart["version"]
        except yaml.YAMLError as exc:
            exit_message(exc)

    if not version:
        version = get_commit_tag_as_semver()

    return version
