"""Module of Sonar Scanner commands"""

import sys
from enum import Enum

sys.path.append("./senior-ci")

from common import (
    ExitCode,
    exec_command_and_return,
    exit_message,
    get_env_variable,
)
from common.extensions import Extensions


class SonarScannerType(Enum):
    FLUTTER = 1


class SonarScanner:
    def __init__(
        self,
        extensions: Extensions = Extensions(),
        sonar_scanner_type: SonarScannerType = None,
    ) -> None:
        self.extensions = extensions
        self.sonar_scanner_type = sonar_scanner_type

    def preview(self):
        self.extensions.before_sonar_preview()

        base_sonar_scanner = self._create_base_sonar_scanner()

        ci_build_ref = get_env_variable("CI_BUILD_REF")
        ci_build_ref_name = get_env_variable("CI_BUILD_REF_NAME")

        command_result_sonar = exec_command_and_return(
            f"{base_sonar_scanner} -Dsonar.gitlab.commit_sha={ci_build_ref} -Dsonar.gitlab.ref_name={ci_build_ref_name} -Dsonar.analysis.mode=preview"
        )

        print(command_result_sonar.output)

        if command_result_sonar.exit_code == ExitCode.ERROR:
            exit_message("Analise do sonar finalizada com erro, verifique.")

        self.extensions.after_sonar_preview()

    def publish(self):
        self.extensions.before_sonar_send()

        base_sonar_scanner = self._create_base_sonar_scanner()

        ci_project_url = get_env_variable("CI_PROJECT_URL")

        command_result_sonar = exec_command_and_return(
            f"{base_sonar_scanner} -Dsonar.links.scm={ci_project_url}"
        )

        print(command_result_sonar.output)

        if command_result_sonar.exit_code == ExitCode.ERROR:
            exit_message("Publicação para o sonar finalizada com erro, verifique.")

        self.extensions.after_sonar_send()

    def _create_base_sonar_scanner(self):
        sonar_url = get_env_variable("SONAR_URL")
        ci_project_name = get_env_variable("CI_PROJECT_NAME")
        ci_project_id = get_env_variable("CI_PROJECT_ID")
        sonar_analysis_version = get_env_variable("CI_COMMIT_REF_SLUG")

        base_sonar_scanner = f"sonar-scanner -Dsonar.host.url={sonar_url} -Dsonar.projectKey={ci_project_name} -Dsonar.projectName={ci_project_name} -Dsonar.gitlab.project_id={ci_project_id} -Dsonar.issuesReport.console.enable=true -Dsonar.sourceEncoding=UTF-8 -Dsonar.projectVersion={sonar_analysis_version}"

        if self.sonar_scanner_type == SonarScannerType.FLUTTER:
            base_sonar_scanner = f"{base_sonar_scanner} -Dsonar.dart.analysis.reportPath=analyzer-output.txt"

        return base_sonar_scanner
