import sys
from datetime import datetime

sys.path.append("./senior-ci")

from common import (
    get_env_variable,
)
from common.graphql_client import GraphqlClient


class CheckDeprecatedPrimitives:
    def __init__(self, client_graphql: GraphqlClient = GraphqlClient()) -> None:
        self.client_graphql = client_graphql

    def check(self):
        """Check for deprecated primitives on commit"""

        query = """
            query ($projectId: Int!, $commitSha: String!) {
                checkForDeprecatedPrimitives(
                    projectId: $projectId, commitSha: $commitSha
                ) {
                    success
                    reason
                    lastDeprecatedDate
                }
            }
        """

        params = {
            "projectId": int(get_env_variable("CI_PROJECT_ID")),
            "commitSha": get_env_variable("CI_COMMIT_SHA"),
        }

        result = self.client_graphql.call(query, params)

        output = CheckDeprecatedPrimitivesOutput(result["checkForDeprecatedPrimitives"])

        return output


class CheckDeprecatedPrimitivesOutput:
    def __init__(self, result: dict) -> None:
        self.success = result["success"]
        self.reason = result["reason"]

        if result["lastDeprecatedDate"]:
            self.last_deprecated_date = datetime.strptime(
                result["lastDeprecatedDate"], "%Y-%m-%d"
            )
