import re

from common import get_env_variable

from jira_manager import JiraManager


class ChangelogReader:
    def __init__(
        self, changelog_base_path, tag, jira_manager: JiraManager = JiraManager()
    ):
        self.jira_manager = jira_manager

        self.issue_pattern = re.compile(
            r"\*?\s*?\[#?(?P<key>\w+-\d+)\](?P<link>\(http[s]?:\/\/[^)]*\))?\s*-?\s*(?P<summary>.*)",
            re.MULTILINE,
        )

        self.changelog_path = f"{changelog_base_path}/CHANGELOG.md"
        self.tag = tag.replace("v", "").replace("-", ".")

        project_url = get_env_variable("CI_PROJECT_URL")

        self.changelog_url = (
            f"{project_url}/-/blob/{tag}{self.changelog_path.replace('.','', 1)}"
        )

    def read_issues(self):
        issues = []
        tag_section_pattern = re.compile(r"^# [0-9\.]+")
        with open(self.changelog_path, "r", encoding="utf-8") as changelog:
            line = changelog.readline()
            is_in_tag_section = False
            while line:
                if self.tag in line:
                    is_in_tag_section = True
                    line = changelog.readline()
                    continue

                started_other_section = is_in_tag_section and tag_section_pattern.match(
                    line
                )
                if started_other_section:
                    break

                if is_in_tag_section and self.issue_pattern.match(line):
                    issue_key = self._issue_key_from(line)
                    issue = self.jira_manager.get_issue(issue_key)
                    issues.append(issue)

                line = changelog.readline()

            changelog.close()

        return issues

    def _issue_key_from(self, line):
        matches = self.issue_pattern.search(line)
        return matches.group("key")
